variable

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 9, 2025 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CheckType

func CheckType(e interface{}) string

func ConvertMapSosIntoMapSoI

func ConvertMapSosIntoMapSoI(original map[string]string) map[string]interface{}

Convert `map[string]string` into `map[string]interface{}`

func ConvertSogtIntoSoif

func ConvertSogtIntoSoif[V interface{}](input []*V) []interface{}

Convert `[]*struct` into `[]interface{}`

func ConvertSoi64IntoSoif

func ConvertSoi64IntoSoif(input []int64) []interface{}

Convert `[]int64` into `[]interface{}`

func ConvertSoifIntoSof64

func ConvertSoifIntoSof64(input []interface{}) []float64

Convert `[]interface` into `[]float64`

func ConvertSoifIntoSoi

func ConvertSoifIntoSoi(input []interface{}) []int

Convert `[]interface{}` into `[]int`

func ConvertSoifIntoSoi64

func ConvertSoifIntoSoi64(input []interface{}) []int64

Convert `[]interface{}` into `[]int64`

func ConvertSoifIntoSos

func ConvertSoifIntoSos(input []interface{}) []string

Convert `[]interface{}` into `[]string`

func ConvertSosIntoSoif

func ConvertSosIntoSoif(input []string) []interface{}

Convert `[]string` into `[]interface{}`

func GetValueFromMap

func GetValueFromMap(data map[string]interface{}, key string, defaultValue any) any

Get map element value by key

func Pbool

func Pbool(v bool) *bool

Pbool returns a pointer to the bool value passed in.

func PboolValue

func PboolValue(v *bool) bool

PboolValue returns the value of the bool pointer passed in or false if the pointer is nil.

func Pint

func Pint(v int) *int

Pint returns a pointer to the integer value passed in.

func PprimitiveDate

func PprimitiveDate(v primitive.DateTime) *primitive.DateTime

String returns a pointer to the mongodb primitive.DateTime value passed in.

func Pstring

func Pstring(v string) *string

Pstring returns a pointer to the string value passed in.

func PstringValue

func PstringValue(v *string) string

PstringValue returns the value of the string pointer passed in or "" if the pointer is nil.

func VariablePuint64IntoPuint

func VariablePuint64IntoPuint(i *uint64) *uint

convert pointer Uint64 into pointer Uint

func VariablePuintIntoPuint64

func VariablePuintIntoPuint64(i *uint) *uint64

convert pointer Uint into pointer Uint64

Types

This section is empty.

Jump to