Documentation
¶
Index ¶
- func CheckType(e interface{}) string
- func ConvertMapSosIntoMapSoI(original map[string]string) map[string]interface{}
- func ConvertSogtIntoSoif[V interface{}](input []*V) []interface{}
- func ConvertSoi64IntoSoif(input []int64) []interface{}
- func ConvertSoifIntoSof64(input []interface{}) []float64
- func ConvertSoifIntoSoi(input []interface{}) []int
- func ConvertSoifIntoSoi64(input []interface{}) []int64
- func ConvertSoifIntoSos(input []interface{}) []string
- func ConvertSosIntoSoif(input []string) []interface{}
- func GetValueFromMap(data map[string]interface{}, key string, defaultValue any) any
- func Pbool(v bool) *bool
- func PboolValue(v *bool) bool
- func Pint(v int) *int
- func PprimitiveDate(v primitive.DateTime) *primitive.DateTime
- func Pstring(v string) *string
- func PstringValue(v *string) string
- func VariablePuint64IntoPuint(i *uint64) *uint
- func VariablePuintIntoPuint64(i *uint) *uint64
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConvertMapSosIntoMapSoI ¶
Convert `map[string]string` into `map[string]interface{}`
func ConvertSogtIntoSoif ¶
func ConvertSogtIntoSoif[V interface{}](input []*V) []interface{}
Convert `[]*struct` into `[]interface{}`
func ConvertSoi64IntoSoif ¶
func ConvertSoi64IntoSoif(input []int64) []interface{}
Convert `[]int64` into `[]interface{}`
func ConvertSoifIntoSof64 ¶
func ConvertSoifIntoSof64(input []interface{}) []float64
Convert `[]interface` into `[]float64`
func ConvertSoifIntoSoi ¶
func ConvertSoifIntoSoi(input []interface{}) []int
Convert `[]interface{}` into `[]int`
func ConvertSoifIntoSoi64 ¶
func ConvertSoifIntoSoi64(input []interface{}) []int64
Convert `[]interface{}` into `[]int64`
func ConvertSoifIntoSos ¶
func ConvertSoifIntoSos(input []interface{}) []string
Convert `[]interface{}` into `[]string`
func ConvertSosIntoSoif ¶
func ConvertSosIntoSoif(input []string) []interface{}
Convert `[]string` into `[]interface{}`
func GetValueFromMap ¶
Get map element value by key
func PboolValue ¶
PboolValue returns the value of the bool pointer passed in or false if the pointer is nil.
func PprimitiveDate ¶
String returns a pointer to the mongodb primitive.DateTime value passed in.
func PstringValue ¶
PstringValue returns the value of the string pointer passed in or "" if the pointer is nil.
func VariablePuint64IntoPuint ¶
convert pointer Uint64 into pointer Uint
func VariablePuintIntoPuint64 ¶
convert pointer Uint into pointer Uint64
Types ¶
This section is empty.